Properties Methods Events Direct Link

# Class Ext.ensible.cal.ReminderField

Package: | Ext.ensible.cal
Defined In: | ReminderField.js
Class: | ReminderField
Extends: | Object

A custom combo used for choosing a reminder setting for an event.

This is pretty much a standard combo that is simply pre-configured for the options needed by the calendar components. The default configs are as follows:

    width: 200,
    fieldLabel: 'Reminder',
    mode: 'local',
    triggerAction: 'all',
    forceSelection: true,
    displayField: 'desc',
    valueField: 'value',
    noneText: 'None',
    atStartTimeText: 'At start time',
    reminderValueFormat: '{0} {1} before start'

To customize the descriptions in the dropdown list override the following methods: getMinutesText, getHoursText, getDaysText and getWeeksText.

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| ReminderField( `Object config` ) Parameters: `config` : Object The config object Returns: void | ReminderField
| getDaysText( `Number numDays` ) : String Returns the unit text to use for a reminder that has a specified number of days prior to the due time (defaults to 'd... Returns the unit text to use for a reminder that has a specified number of days prior to the due time (defaults to 'day' when the passed value === 1, else 'days'). Parameters: `numDays` : Number The number of days prior to the due time Returns: `String` The unit text | ReminderField
| getHoursText( `Number numHours` ) : String Returns the unit text to use for a reminder that has a specified number of hours prior to the due time (defaults to '... Returns the unit text to use for a reminder that has a specified number of hours prior to the due time (defaults to 'hour' when the passed value === 1, else 'hours'). Parameters: `numHours` : Number The number of hours prior to the due time Returns: `String` The unit text | ReminderField
| getMinutesText( `Number numMinutes` ) : String Returns the unit text to use for a reminder that has a specified number of minutes prior to the due time (defaults to... Returns the unit text to use for a reminder that has a specified number of minutes prior to the due time (defaults to 'minute' when the passed value === 1, else 'minutes'). Parameters: `numMinutes` : Number The number of minutes prior to the due time Returns: `String` The unit text | ReminderField
| getValueList() : Array Returns the list of reminder values used as the contents of the combo list. This method is provided so that the value... Returns the list of reminder values used as the contents of the combo list. This method is provided so that the value list can be easily overridden as needed. Parameters: None. Returns: `Array` A 2-dimensional array of type [{String}, {String}] which contains the value and description respectively of each item in the combo list. By default the value is the number of minutes for the selected time value (e.g., value 120 == '2 hours') with empty string for no value, but these can be set to anything. | ReminderField
| getWeeksText( `Number numWeeks` ) : String Returns the unit text to use for a reminder that has a specified number of weeks prior to the due time (defaults to '... Returns the unit text to use for a reminder that has a specified number of weeks prior to the due time (defaults to 'week' when the passed value === 1, else 'weeks'). Parameters: `numWeeks` : Number The number of weeks prior to the due time Returns: `String` The unit text | ReminderField

## Public Events

This class has no public events.